=======
History
=======

0.3.0 (2021-07-23)
------------------

* Changed "hours age" parameter to "since" to improve usability in scripts.
* Added notifier abstraction
* Added the possibility to use multiple notifiers

  * Currently, there is only one notifier (pushsafer)

* Changed options name to reflect these changes

0.2.0 (2021-07-21)
------------------

* Changed "after" parameter to "hours ago" to improve usability in scripts.

0.1.0 (2021-07-21)
------------------

* First release on PyPI.
